summaryrefslogtreecommitdiff
path: root/xmake/scripts/base/main.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2015-06-09 10:14:56 +0800
committerruki <[email protected]>2015-06-09 10:14:56 +0800
commitd9051004d0b3b24f804e0bfffc5050e260018084 (patch)
treed65e74ba1caf4041e1ecaf2038f23196cedf4aab /xmake/scripts/base/main.lua
parent387b3666c4d952e01b96bce7e9bc51ed86fe986f (diff)
rename xmake.xproj to xmake.lua
Diffstat (limited to 'xmake/scripts/base/main.lua')
-rw-r--r--xmake/scripts/base/main.lua18
1 files changed, 9 insertions, 9 deletions
diff --git a/xmake/scripts/base/main.lua b/xmake/scripts/base/main.lua
index 7f8087180..544a15005 100644
--- a/xmake/scripts/base/main.lua
+++ b/xmake/scripts/base/main.lua
@@ -64,7 +64,7 @@ local menu =
, {'r', "rebuild", "k", nil, "Rebuild the project." }
, {}
- , {'f', "file", "kv", "xmake.xproj","Read a given xmake.xproj file." }
+ , {'f', "file", "kv", "xmake.lua", "Read a given xmake.lua file." }
, {'P', "project", "kv", nil, "Change to the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -98,7 +98,7 @@ local menu =
, options =
{
{'n', "name", "kv", nil, "The project name." }
- , {'f', "file", "kv", "xmake.xproj","Create a given xmake.xproj file." }
+ , {'f', "file", "kv", "xmake.lua", "Create a given xmake.lua file." }
, {'P', "project", "kv", nil, "Create from the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -223,7 +223,7 @@ local menu =
, function () return platform.menu("config") end
, {}
- , {'f', "file", "kv", "xmake.xproj","Read a given xmake.xproj file." }
+ , {'f', "file", "kv", "xmake.lua", "Read a given xmake.lua file." }
, {'P', "project", "kv", nil, "Change to the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -286,7 +286,7 @@ local menu =
-- options
, options =
{
- {'f', "file", "kv", "xmake.xproj","Read a given xmake.xproj file." }
+ {'f', "file", "kv", "xmake.lua", "Read a given xmake.lua file." }
, {'P', "project", "kv", nil, "Change to the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -318,7 +318,7 @@ local menu =
-- options
, options =
{
- {'f', "file", "kv", "xmake.xproj","Read a given xmake.xproj file." }
+ {'f', "file", "kv", "xmake.lua", "Read a given xmake.lua file." }
, {'P', "project", "kv", nil, "Change to the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -353,7 +353,7 @@ local menu =
, {nil, "debugger", "kv", "auto", "Set the debugger path." }
, {}
- , {'f', "file", "kv", "xmake.xproj","Read a given xmake.xproj file." }
+ , {'f', "file", "kv", "xmake.lua", "Read a given xmake.lua file." }
, {'P', "project", "kv", nil, "Change to the given project directory."
, "Search priority:"
, " 1. The Given Command Argument"
@@ -453,8 +453,8 @@ function main._prepare_project()
-- save the project directory
xmake._PROJECT_DIR = options.project
- -- init the xmake.xproj file path
- options.file = options.file or options._DEFAULTS.file or "xmake.xproj"
+ -- init the xmake.lua file path
+ options.file = options.file or options._DEFAULTS.file or "xmake.lua"
if not path.is_absolute(options.file) then
options.file = path.absolute(options.file, options.project)
end
@@ -497,7 +497,7 @@ function main._prepare_project()
if not options[k] then options[k] = v end
end
- -- load xmake.xproj file
+ -- load xmake.lua file
return project.loadxproj(options.file)
end